@@ -14,18 +14,23 @@ import requests
 from pdf2image import convert_from_bytes, convert_from_path
 from prettytable import PrettyTable
 
-from disclosure_extractor.calculate import estimate_investment_net_worth, color
+from disclosure_extractor.calculate import (
+    color,
+    estimate_investment_net_worth,
+    estimate_investment_net_worth_JEF,
+)
 from disclosure_extractor.data_processing import process_document
 from disclosure_extractor.image_processing import (
-    extract_contours_from_page,
     CheckboxesNotFound,
+    extract_contours_from_page,
 )
+from disclosure_extractor.jef.extraction import extract_content
 from disclosure_extractor.judicial_watch_utils import (
-    get_investment_pages,
-    extract_section_VII,
     extract_section_I_to_VI,
-    identify_sections,
+    extract_section_VII,
+    get_investment_pages,
     get_text_fields,
+    identify_sections,
     process_addendum,
 )
 from disclosure_extractor.post_processing import _fine_tune_results
@@ -298,3 +303,20 @@ def extract_financial_document(
     cleaned_data = _fine_tune_results(results)
 
     return cleaned_data
+
+
+def process_jef_document(
+    file_path: str,
+    calculate_wealth: bool = False,
+) -> Dict:
+    """Extract content from JEF document
+
+    :param file_path:Path to the PDF
+    :return: Extracted content
+    """
+
+    results = extract_content(file_path)
+    if calculate_wealth:
+        results["wealth"] = estimate_investment_net_worth_JEF(results)
+    results["success"] = True
+    return results
